---
title: Title タイトル
rhead: RIGHT-HEAD
lhead: LEFT-HEAD
---

# Section 1 セクション{#sec:1}

![a](pgf.ipynb){#fig:pgf}

![a](png.ipynb){#fig:png}

[@fig:pgf]

## Subsection あいう1

![a](png.ipynb){#fig:png width=4cm}
![a [@fig:pgf]](png.ipynb){#fig:png width=4cm}
: eee {#fig:xxx}

![a](png.ipynb){#fig:png width=4cm}
![a [@fig:pgf]](png.ipynb){#fig:png width=4cm}
: eee {#fig:xxx}

あいう @fig:xxx
えお [@fig:png_]

### Subsubsection 2

あいう

[@panpdf], [@panflute]
